#!/usr/bin/env python

import json
import os
import sys
import time
import traceback

from mozdevice import ADBAndroid

def dump_scriptvars():
    """
    Read the variables passed from the Docker host via the environment
    and create a json file /builds/taskcluster/scriptvars.json containing
    their values.

    The payload script will read this file and recreate the necessary
    environment

    This is necessary due to the fact that taskcluster-worker does not
    pass the environment variables in its environment to its payload
    script.

    """
    names = (
        "TESTDROID_PROJECT_ID",
        "TESTDROID_BUILD_ID",
        "TESTDROID_RUN_ID",
        "HOME",
        "HOSTNAME",
        "TASKCLUSTER_ACCESS_TOKEN",
        "TASKCLUSTER_CLIENT_ID",
        "TC_CONTAINER_IP",
        "TC_DEVICE_NAME",
        "TC_DEVICE_SERIAL",
        "TC_WORKER_GROUP",
        "TC_WORKER_TYPE",
    )
    variables = dict( (k, os.environ[k]) for k in names )

    with open('/builds/taskcluster/scriptvars.json', 'w') as scriptvars:
        scriptvars.write(json.dumps(variables))

def main():
    dump_scriptvars()

    max_attempts = 3
    wait_time = 60
    serial = os.environ['TC_DEVICE_SERIAL']
    name = os.environ['TC_DEVICE_NAME']
    for attempt in range(max_attempts):
        try:
            print('Attempt {} to access device {} {}'.format(attempt, name, serial))
            device = ADBAndroid(device=serial)
            device_ip_address = device.get_ip_address()
            if device_ip_address:
                print('device {} {} ip address {}'.format(name, serial, device_ip_address))
                break
        except:
            sys.stderr.write('Exception accessing device')
            sys.stderr.write(traceback.format_exc())
        time.sleep(wait_time)

if __name__ == "__main__":
    main()
